==> haskell-cassava-megaparsec-2.0.0-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 2.0.0
id: cassava-megaparsec-2.0.0-80jq9VSwrKIHSIJRLbDGwT
key: cassava-megaparsec-2.0.0-80jq9VSwrKIHSIJRLbDGwT
license: MIT
maintainer: Mark Karpov <markkarpov92@gmail.org>
author: Mark Karpov <markkarpov92@gmail.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 234644df844fa9126de566560feaddcb
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cassava-megaparsec-2.0.0
hs-libraries: HScassava-megaparsec-2.0.0-80jq9VSwrKIHSIJRLbDGwT
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-IuCc7lBgsCs4cTYqebFZsu
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.0.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava-megaparsec
version: 2.0.0
id: cassava-megaparsec-2.0.0-BDuT09Ivw3B2kURZqtmmdG
key: cassava-megaparsec-2.0.0-BDuT09Ivw3B2kURZqtmmdG
license: MIT
maintainer: Mark Karpov <markkarpov92@gmail.org>
author: Mark Karpov <markkarpov92@gmail.org>
homepage: https://github.com/stackbuilders/cassava-megaparsec
synopsis: Megaparsec parser of CSV files that plays nicely with Cassava
description:
    Megaparsec parser of CSV files that plays nicely with Cassava.
category: Text, Web, CSV, Parsing
abi: 39e89492535befbe9e75369a9773de53
exposed: True
exposed-modules:
    Data.Csv.Parser.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/cassava-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cassava-megaparsec-2.0.0
hs-libraries: HScassava-megaparsec-2.0.0-BDuT09Ivw3B2kURZqtmmdG
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    cassava-0.5.1.0-4shXkswd3EKBehGwHVQSuJ
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
